diff --git a/.travis.yml b/.travis.yml
index 411f6931..9f5dd1d0 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -1,10 +1,9 @@
 language: go
 go:
-  - 1.13.x
   - 1.14.x
 install:
   # Fetch dependencies
-  - curl -sfL https://install.goreleaser.com/github.com/golangci/golangci-lint.sh | sh -s -- -b $GOPATH/bin v1.23.6
+  - curl -sfL https://install.goreleaser.com/github.com/golangci/golangci-lint.sh | sh -s -- -b $GOPATH/bin v1.24.0
   - GO111MODULE=on go mod download
 script:
   - ./configure && make test
diff --git a/CHANGELOG.md b/CHANGELOG.md
index ddd3bc68..c3616241 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -2,10 +2,25 @@
 
 ## Release Hightlights
 
+## Important Notes
+
+## Breaking Changes
+
+## Changes since v5.1.0
+
+# v5.1.0
+
+## Release Hightlights
+- Bump to Go 1.14
+- Reduced number of Google API requests for group validation
+- Support for Redis Cluster
+- Support for overriding hosts in hosts file
+
 ## Important Notes
 - [#335] The session expiry for the OIDC provider is now taken from the Token Response (expires_in) rather than from the id_token (exp)
 
 ## Breaking Changes
+N/A
 
 ## Changes since v5.0.0
 
diff --git a/Dockerfile b/Dockerfile
index b44e62f9..bea6fe1e 100644
--- a/Dockerfile
+++ b/Dockerfile
@@ -1,7 +1,7 @@
 FROM golang:1.14-buster AS builder
 
 # Download tools
-RUN curl -sfL https://install.goreleaser.com/github.com/golangci/golangci-lint.sh | sh -s -- -b $(go env GOPATH)/bin v1.23.6
+RUN curl -sfL https://install.goreleaser.com/github.com/golangci/golangci-lint.sh | sh -s -- -b $(go env GOPATH)/bin v1.24.0
 
 # Copy sources
 WORKDIR $GOPATH/src/github.com/pusher/oauth2_proxy
diff --git a/Dockerfile.arm64 b/Dockerfile.arm64
index 03929a80..8bfde8ae 100644
--- a/Dockerfile.arm64
+++ b/Dockerfile.arm64
@@ -1,7 +1,7 @@
 FROM golang:1.14-buster AS builder
 
 # Download tools
-RUN curl -sfL https://install.goreleaser.com/github.com/golangci/golangci-lint.sh | sh -s -- -b $(go env GOPATH)/bin v1.23.6
+RUN curl -sfL https://install.goreleaser.com/github.com/golangci/golangci-lint.sh | sh -s -- -b $(go env GOPATH)/bin v1.24.0
 
 # Copy sources
 WORKDIR $GOPATH/src/github.com/pusher/oauth2_proxy
diff --git a/Dockerfile.armv6 b/Dockerfile.armv6
index f41f7765..da7310d2 100644
--- a/Dockerfile.armv6
+++ b/Dockerfile.armv6
@@ -1,7 +1,7 @@
 FROM golang:1.14-buster AS builder
 
 # Download tools
-RUN curl -sfL https://install.goreleaser.com/github.com/golangci/golangci-lint.sh | sh -s -- -b $(go env GOPATH)/bin v1.23.6
+RUN curl -sfL https://install.goreleaser.com/github.com/golangci/golangci-lint.sh | sh -s -- -b $(go env GOPATH)/bin v1.24.0
 
 # Copy sources
 WORKDIR $GOPATH/src/github.com/pusher/oauth2_proxy
diff --git a/configure b/configure
index 10af15e6..c8edb308 100755
--- a/configure
+++ b/configure
@@ -5,8 +5,8 @@ GREEN='\033[0;32m'
 BLUE='\033[0;34m'
 NC='\033[0m'
 
-if [ -z "${BASH_VERSINFO}" ] || [ -z "${BASH_VERSINFO[0]}" ] || [ ${BASH_VERSINFO[0]} -lt 4 ]; then 
-  echo "This script requires Bash version >= 4"; exit 1; 
+if [ -z "${BASH_VERSINFO}" ] || [ -z "${BASH_VERSINFO[0]}" ] || [ ${BASH_VERSINFO[0]} -lt 4 ]; then
+  echo "This script requires Bash version >= 4"; exit 1;
 fi
 
 declare -A tools=()
@@ -81,7 +81,7 @@ check_for() {
 check_go_version() {
   echo -n "Checking go version... "
   GO_VERSION=$(${tools[go]} version | ${tools[awk]} '{where = match($0, /[0-9]\.[0-9]+\.[0-9]*/); if (where != 0) print substr($0, RSTART, RLENGTH)}')
-  vercomp $GO_VERSION 1.12
+  vercomp $GO_VERSION 1.14
   case $? in
     0) ;&
     1)
@@ -91,7 +91,7 @@ check_go_version() {
       ;;
     2)
       printf "${RED}"
-      echo "$GO_VERSION < 1.12"
+      echo "$GO_VERSION < 1.14"
       exit 1
       ;;
   esac
diff --git a/go.mod b/go.mod
index 8cc27a2e..541bf320 100644
--- a/go.mod
+++ b/go.mod
@@ -1,6 +1,6 @@
 module github.com/pusher/oauth2_proxy
 
-go 1.13
+go 1.14
 
 require (
 	github.com/BurntSushi/toml v0.3.1
diff --git a/dist.sh b/dist.sh
index 37052125..516d86f1 100755
--- a/dist.sh
+++ b/dist.sh
@@ -7,10 +7,10 @@ if [[ -z ${BINARY} ]] || [[ -z ${VERSION} ]]; then
 	exit 1
 fi
 
 # Check for Go version 1.13.*
 GO_VERSION=$(go version | awk '{print $3}')
-if [[ ! "${GO_VERSION}" =~ ^go1.13.* ]]; then
-	echo "Go version must be >= go1.13"
+if [[ ! "${GO_VERSION}" =~ ^go1.14.* ]]; then
+	echo "Go version must be >= go1.14"
 	exit 1
 fi
 
@@ -7,10 +7,10 @@ if [[ -z ${BINARY} ]] || [[ -z ${VERSION} ]]; then
 fi
 
-# Check for Go version 1.13.*
+# Check for Go version 1.14.*
 GO_VERSION=$(go version | awk '{print $3}')